@@ -3,7 +3,7 @@ from pathlib import Path
 from typing import Optional, Union
 
 from ._logger import logger
-from .dev._integrity import check_integrity
+from .dev._consecutiveness import check_consecutiveness
 from .dev._jupyter_communicate import notebook_path
 from .dev._jupyter_lab_commands import _save_notebook
 from .dev._meta_store import MetaContainer, MetaStore
@@ -12,18 +12,11 @@ from .dev._notebook import Notebook, read_notebook
 
 def get_title(nb: Notebook) -> Optional[str]:
     """Get title of the notebook."""
-    title_error = (
-        "Warning: No title! Please update & save your notebook so that it has a"
-        " markdown cell with the title: # My title"
-    )
-
     if nb.cells[0]["cell_type"] != "markdown":
-        logger.info(title_error)
         title = None
     else:
         title = nb.cells[0]["source"][0]
         if not title.startswith("# "):
-            logger.info(title_error)
             title = None
         else:
             title = title.lstrip("#").strip(" .")
@@ -48,7 +41,7 @@ class MetaLive:
         self._time_run = time_run
 
     @property
-    def title(self):
+    def title(self) -> Optional[str]:
         """Get the title of the notebook.
 
         The first cell should contain markdown text formatted as a title.
@@ -64,18 +57,24 @@ class MetaLive:
         return infer_dependencies_from_file(self._nb_path)
 
     @property
-    def integrity(self):
-        """Compute integrity of the notebook.
+    def consecutive_cells(self) -> bool:
+        """Have notebook cells been consecutively executed?
 
-        Returns those cell transitions that violate execution at increments of 1
+        Logs cell transitions that violate execution at increments of 1
         as a list of tuples.
         """
         if self._env == "lab":
             _save_notebook()
         elif self._env != "test":
-            logger.info("Save the notebook before running the integrity check.")
+            logger.info("Save the notebook before checking for consecutiveness.")
         nb = read_notebook(self._nb_path)
-        return check_integrity(nb, ignore_code=".live.integrity")
+        violations = check_consecutiveness(
+            nb, calling_statement=".live.consecutive_cells"
+        )
+        if len(violations) > 0:
+            return False
+        else:
+            return True
 
     @property
     def time_run(self):
