@@ -2,52 +2,34 @@ from typing import Optional
 
 from ._logger import logger
 from ._meta import _load_meta
-from .dev._integrity import check_integrity
+from .dev._check_last_cell import check_last_cell
+from .dev._consecutiveness import check_consecutiveness
 from .dev._jupyter_lab_commands import _save_notebook
-from .dev._notebook import Notebook, read_notebook
-
-
-def _check_last_cell(nb: Notebook, code: str) -> bool:
-    last_code_cell = None
-    for cell in nb.cells:
-        if cell["cell_type"] == "code" and cell["source"] != []:
-            last_code_cell = cell
-
-    if last_code_cell is not None and code in "".join(last_code_cell["source"]):
-        return True
-    else:
-        return False
+from .dev._notebook import read_notebook
 
 
 def publish(
     *,
     version: Optional[str] = None,
-    dependency: bool = True,
-    integrity: bool = True,
     i_confirm_i_saved: bool = False,
-    last_cell: bool = True,
     **kwargs,
 ):
     """Publish your notebook before sharing it to ensure it's reproducible.
 
     This function should be called in the last code cell of the notebook!
 
-    1. Sets the version.
-    2. Stores dependencies.
-    3. Checks integrity, i.e., whether notebook cells were executed consecutively.
+    1. Checks that the notebook has a title.
+    2. Sets the version.
+    3. Stores dependencies.
+    4. Checks consecutiveness, i.e., whether notebook cells were executed consecutively.
 
-    Returns the integrity check result.
+    Returns the consecutiveness check result.
 
     Args:
         version: If `None`, bumps the version from "draft" to "1", from "1" to "2", etc.
             Otherwise sets the version to the passed version.
-        dependency: If `True`, writes `dependency.live` to `dependency.store`.
-            If `False`, leaves the current `dependency.store` as is.
-        integrity: If `False`, does not check integrity.
         i_confirm_i_saved: Only relevant outside Jupyter Lab as a safeguard against
             losing the editor buffer content because of accidentally publishing.
-        last_cell: If `True`, checks that `publish` is in the last code cell
-            of the notebook.
     """
     meta = _load_meta()
     if "calling_statement" in kwargs:
@@ -55,22 +37,35 @@ def publish(
     else:
         calling_statement = "publish("
 
+    notebook_title = meta.live.title
+    title_error = (
+        "Error: No title! Please update & save your notebook so that it has a"
+        " markdown cell with the title: # My title"
+    )
+
+    if notebook_title is None:
+        raise RuntimeError(title_error)
+
     if meta._env == "lab":
         _save_notebook()
     else:
-        if not i_confirm_i_saved:
+        pretend_no_test_env = (
+            kwargs["pretend_no_test_env"] if "pretend_no_test_env" in kwargs else False
+        )
+        if (
+            meta._env == "test" and not pretend_no_test_env
+        ):  # do not raise error in test environment
+            pass
+        elif not i_confirm_i_saved:
             raise RuntimeError(
                 "Make sure you save the notebook in your editor before publishing!\n"
                 "You can avoid the need for manually saving in Jupyter Lab, which auto-saves the buffer during publish."  # noqa
             )
 
     nb = read_notebook(meta._filepath)
-
-    if last_cell and not _check_last_cell(nb, calling_statement):
-        raise RuntimeError("publish is not at the end of the current notebook.")
-
-    if integrity:
-        check_integrity(nb, ignore_code=calling_statement)
+    if not check_last_cell(nb, calling_statement):
+        raise RuntimeError("Can only publish from the last code cell of the notebook.")
+    check_consecutiveness(nb)
 
     if version is not None:
         meta.store.version = version
@@ -87,12 +82,7 @@ def publish(
                 " string."
             )
 
-    info = f"Bumped notebook version to {version}."
+    meta.store.dependency = meta.live.dependency
+    logger.info(f"Bumped notebook version to {version} & wrote dependencies.")
 
-    if dependency:
-        meta.store.dependency = meta.live.dependency
-        info += " Wrote dependencies to dependency store."
-
-    logger.info(info)
-
-    meta.store.write(restart=False)
+    meta.store.write()
