@@ -5,7 +5,7 @@ Features
 
 .. autofunction:: infer_dependencies_from_nb
 .. autofunction:: infer_dependencies_from_file
-.. autofunction:: check_integrity
+.. autofunction:: check_consecutiveness
 
 Backend
 -------
@@ -18,8 +18,8 @@ Backend
 """
 import nbproject_test as test
 
+from ._consecutiveness import check_consecutiveness
 from ._dependency import infer_dependencies_from_file, infer_dependencies_from_nb
 from ._initialize import initialize_metadata
-from ._integrity import check_integrity
 from ._jupyter_communicate import notebook_path
 from ._notebook import Notebook, read_notebook, write_notebook
