@@ -6,11 +6,7 @@ from nbproject.dev._jupyter_communicate import (
     query_server,
     running_servers,
 )
-from nbproject.dev._jupyter_lab_commands import (
-    _reload_and_restart_notebook,
-    _reload_shutdown,
-    _save_notebook,
-)
+from nbproject.dev._jupyter_lab_commands import _reload_notebook, _save_notebook
 
 
 def test_jupyter_not_running():
@@ -40,5 +36,4 @@ def test_jupyter_not_running():
 
 def test_juplab_nothing_happens():
     _save_notebook()
-    _reload_shutdown()
-    _reload_and_restart_notebook()
+    _reload_notebook()
